@@ -8,13 +8,16 @@ import os
 import pathlib
 import shutil
 import subprocess
+import time
 import unittest.mock
 import urllib.error
 import urllib.request
-from collections.abc import Callable, Generator, Iterator, Sequence
+from collections.abc import Callable, Generator, Iterator, Sequence, Set
 from typing import Any
 from unittest.mock import MagicMock
 
+import psutil
+
 
 def get_init_system() -> str:
     """Return the name of the running init system (PID 1)."""
@@ -52,8 +55,8 @@ def import_module_from_file(path: pathlib.Path) -> Any:
     return module
 
 
-def pidof(program):
-    """Find the process ID of a running program.
+def pids_of(program: str) -> set[int]:
+    """Find the process IDs of a running program.
 
     This function wraps the pidof command and returns a set of
     process IDs.
@@ -93,7 +96,7 @@ def run_test_executable(
             test_process.kill()
 
 
-def _id(obj):
+def _id(obj: Any) -> Any:
     return obj
 
 
@@ -126,7 +129,7 @@ def wrap_object(
     mock = MagicMock()
     real_attribute = getattr(target, attribute)
 
-    def mocked_attribute(self, *args, **kwargs):
+    def mocked_attribute(self: object, *args: Any, **kwargs: Any) -> Any:
         if include_instance:
             mock(self, *args, **kwargs)
         else:
@@ -135,3 +138,38 @@ def wrap_object(
 
     with unittest.mock.patch.object(target, attribute, mocked_attribute):
         yield mock
+
+
+def wait_for_sleeping_state(pid: int, timeout: float = 5.0) -> None:
+    """Wait for sleep command to enter sleeping state."""
+    proc = psutil.Process(pid)
+    waited = 0.0
+    last_state = ""
+    while waited < timeout:
+        last_state = proc.status()
+        if last_state == "sleeping":
+            return
+
+        time.sleep(0.1)
+        waited += 0.1
+
+    raise TimeoutError(
+        f"{pid=} did not enter 'sleeping' state after {timeout=} seconds."
+        f" Got {last_state!r} instead."
+    )
+
+
+def wait_for_process_to_appear(
+    process: str, already_running: Set[int], timeout: float = 5.0
+) -> int:
+    """Wait for process to appear and return its PID."""
+    waited = 0.0
+    while waited < timeout:
+        pids = pids_of(process) - already_running
+        if pids:
+            assert len(pids) == 1, f"Found more than one PID for {process!r}"
+            return pids.pop()
+        time.sleep(0.1)
+        timeout -= 0.1
+
+    raise TimeoutError(f"PID for {process!r} not found within {timeout=} seconds.")
