@@ -37,7 +37,12 @@ from unittest.mock import MagicMock
 import psutil
 
 import apport.fileutils
-from tests.helper import import_module_from_file, read_shebang, run_test_executable
+from tests.helper import (
+    import_module_from_file,
+    read_shebang,
+    run_test_executable,
+    wait_for_sleeping_state,
+)
 from tests.paths import get_data_directory, local_test_environment
 
 try:
@@ -77,9 +82,14 @@ class T(unittest.TestCase):
     TEST_EXECUTABLE = os.path.realpath("/bin/sleep")
     TEST_ARGS = ["86400"]
     maxDiff = None
+    orig_core_dir: str
+    orig_cwd: str
+    orig_environ: dict[str, str]
+    orig_ignore_file: str
+    orig_report_dir: str
 
     @classmethod
-    def setUpClass(cls):
+    def setUpClass(cls) -> None:
         cls.orig_environ = os.environ.copy()
         os.environ |= local_test_environment()
 
@@ -89,7 +99,7 @@ class T(unittest.TestCase):
         cls.orig_report_dir = apport.fileutils.report_dir
 
     @classmethod
-    def tearDownClass(cls):
+    def tearDownClass(cls) -> None:
         os.environ.clear()
         os.environ.update(cls.orig_environ)
         apport.fileutils.core_dir = cls.orig_core_dir
@@ -97,7 +107,7 @@ class T(unittest.TestCase):
         apport.fileutils.report_dir = cls.orig_report_dir
         os.chdir(cls.orig_cwd)
 
-    def setUp(self):
+    def setUp(self) -> None:
         # use local report dir
         self.report_dir = tempfile.mkdtemp()
         os.environ["APPORT_REPORT_DIR"] = self.report_dir
@@ -123,9 +133,9 @@ class T(unittest.TestCase):
         os.chdir("/tmp")
 
         # expected report name for test executable report
-        self.test_report = None
+        self.test_report: str | None = None
 
-    def tearDown(self):
+    def tearDown(self) -> None:
         # permit tests to leave behind test_report, but nothing else
         if self.test_report and os.path.exists(self.test_report):
             apport.fileutils.delete_report(self.test_report)
@@ -135,7 +145,7 @@ class T(unittest.TestCase):
             shutil.rmtree(self.report_dir)
             shutil.rmtree(self.workdir)
 
-    def test_empty_core_dump(self):
+    def test_empty_core_dump(self) -> None:
         """Empty core dumps do not generate a report."""
         test_proc = self.create_test_process()
         try:
@@ -154,6 +164,7 @@ class T(unittest.TestCase):
                 stdin=subprocess.PIPE,
                 stderr=subprocess.PIPE,
             ) as app:
+                assert app.stdin is not None and app.stderr is not None
                 app.stdin.close()
                 assert app.wait() == 0, app.stderr.read()
                 app.stderr.close()
@@ -229,7 +240,7 @@ class T(unittest.TestCase):
         self.assertNotIn("root", pr["UserGroups"])
 
     @unittest.skip("fix test as multiple instances can be started within 30s")
-    def test_parallel_crash(self):
+    def test_parallel_crash(self) -> None:
         """Only one apport instance is ran at a time."""
         test_proc = self.create_test_process()
         test_proc2 = self.create_test_process("/bin/dd", args=[])
@@ -249,6 +260,7 @@ class T(unittest.TestCase):
                 stdin=subprocess.PIPE,
                 stderr=subprocess.PIPE,
             ) as app:
+                assert app.stdin is not None and app.stderr is not None
                 time.sleep(0.5)  # give it some time to grab the lock
 
                 with subprocess.Popen(
@@ -266,6 +278,7 @@ class T(unittest.TestCase):
                     stdin=subprocess.PIPE,
                     stderr=subprocess.PIPE,
                 ) as app2:
+                    assert app2.stdin is not None and app2.stderr is not None
                     # app should wait indefinitely for stdin, while app2 should
                     # terminate immediately (give it 5 seconds)
                     timeout = 50
@@ -297,7 +310,7 @@ class T(unittest.TestCase):
             test_proc.wait()
             test_proc2.wait()
 
-    def test_unpackaged_binary(self):
+    def test_unpackaged_binary(self) -> None:
         """Unpackaged binaries do not create a report."""
         local_exe = os.path.join(self.workdir, "mybin")
         with open(local_exe, "wb") as dest:
@@ -306,7 +319,7 @@ class T(unittest.TestCase):
         os.chmod(local_exe, 0o755)
         self.do_crash(command=local_exe, expect_report=False)
 
-    def test_unpackaged_script(self):
+    def test_unpackaged_script(self) -> None:
         """Unpackaged scripts do not create a report."""
         local_exe = os.path.join(self.workdir, "myscript")
         with open(local_exe, "w", encoding="utf-8") as f:
@@ -320,14 +333,14 @@ class T(unittest.TestCase):
         os.chdir(self.workdir)
         self.do_crash(command="./myscript", args=[], expect_report=False)
 
-    def test_unsupported_arguments_no_stderr(self):
+    def test_unsupported_arguments_no_stderr(self) -> None:
         """Write failure to log file when stderr is missing.
 
         The kernel calls apport with no stdout and stderr file
         descriptors set.
         """
 
-        def close_stdin_and_stderr():
+        def close_stdin_and_stderr() -> None:
             """Close stdin and stderr"""
             os.close(sys.stdout.fileno())
             os.close(sys.stderr.fileno())
@@ -345,15 +358,15 @@ class T(unittest.TestCase):
         self.assertIn("usage", logged)
         self.assertIn("the following arguments are required: -p/--pid", logged)
 
-    def test_ignore_sigquit(self):
+    def test_ignore_sigquit(self) -> None:
         """Apport ignores SIGQUIT."""
         self.do_crash(sig=signal.SIGQUIT, expect_report=False)
 
-    def test_ignore_sigxcpu(self):
+    def test_ignore_sigxcpu(self) -> None:
         """Apport ignores CPU time limit exceeded (SIGXCPU)."""
         self.do_crash(sig=signal.SIGXCPU, expect_report=False)
 
-    def test_leak_inaccessible_files(self):
+    def test_leak_inaccessible_files(self) -> None:
         """Existence of user-inaccessible files do not leak."""
         local_exe = os.path.join(self.workdir, "myscript")
         with open(local_exe, "w", encoding="utf-8") as f:
@@ -378,7 +391,7 @@ class T(unittest.TestCase):
         self.assertNotIn("InterpreterPath", pr)
         apport.fileutils.delete_report(leak)
 
-    def test_flood_limit(self):
+    def test_flood_limit(self) -> None:
         """Limitation of crash report flood."""
         count = 0
         while count < 7:
@@ -394,7 +407,7 @@ class T(unittest.TestCase):
         self.assertLess(count, 7, "stops flooding after less than 7 repeated crashes")
 
     @unittest.skipIf(os.geteuid() != 0, "this test needs to be run as root")
-    def test_nonreadable_exe(self):
+    def test_nonreadable_exe(self) -> None:
         """Report generation for non-readable executable."""
         # CVE-2015-1324: if a user cannot read an executable, it behaves much
         # like a suid root binary in terms of writing a core dump
@@ -412,7 +425,7 @@ class T(unittest.TestCase):
 
         self.do_crash(command=myexe, expect_corefile=False, uid=8, suid_dumpable=2)
 
-    def test_core_dump_packaged(self):
+    def test_core_dump_packaged(self) -> None:
         """Packaged executables create core dumps on proper ulimits."""
         # for SEGV and ABRT we expect reports and core files
         for sig in (signal.SIGSEGV, signal.SIGABRT):
@@ -430,12 +443,12 @@ class T(unittest.TestCase):
             self.do_crash(expect_corefile=True)
             apport.fileutils.delete_report(self.test_report)
 
-    def test_core_dump_packaged_sigquit(self):
+    def test_core_dump_packaged_sigquit(self) -> None:
         """Packaged executables create core files, no report for SIGQUIT."""
         resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
         self.do_crash(expect_corefile=True, expect_report=False, sig=signal.SIGQUIT)
 
-    def test_core_dump_unpackaged(self):
+    def test_core_dump_unpackaged(self) -> None:
         """Unpackaged executables create core dumps on proper ulimits."""
         local_exe = os.path.join(self.workdir, "mybin")
         with open(local_exe, "wb") as dest:
@@ -454,7 +467,7 @@ class T(unittest.TestCase):
                     sig=sig,
                 )
 
-    def test_core_file_injection(self):
+    def test_core_file_injection(self) -> None:
         """Cannot inject core file."""
         # CVE-2015-1325: ensure that apport does not re-open its .crash report,
         # as that allows us to intercept and replace the report and tinker with
@@ -518,7 +531,7 @@ class T(unittest.TestCase):
 
         self.do_crash(expect_report=False)
 
-    def test_modify_after_start(self):
+    def test_modify_after_start(self) -> None:
         """Ignore executables which got modified after process started."""
         # create executable in a path we can modify which apport regards as
         # likely packaged
@@ -669,7 +682,7 @@ class T(unittest.TestCase):
         self.assertEqual(pr["CoreDump"], b"hel\x01lo")
 
     @unittest.skipIf(os.geteuid() != 0, "this test needs to be run as root")
-    def test_crash_setuid_keep(self):
+    def test_crash_setuid_keep(self) -> None:
         """Report generation for setuid program which stays root."""
         # create suid root executable in a path we can modify which apport
         # regards as likely packaged
@@ -691,7 +704,7 @@ class T(unittest.TestCase):
 
     @unittest.skipUnless(os.path.exists("/bin/ping"), "this test needs /bin/ping")
     @unittest.skipIf(os.geteuid() != 0, "this test needs to be run as root")
-    def test_crash_suid_dumpable_debug(self):
+    def test_crash_suid_dumpable_debug(self) -> None:
         """Report generation for setuid program with suid_dumpable set to 1.
 
         ping has cap_net_raw=ep and therefore do_crash needs root.
@@ -706,7 +719,7 @@ class T(unittest.TestCase):
 
     @unittest.skipUnless(os.path.exists("/bin/ping"), "this test needs /bin/ping")
     @unittest.skipIf(os.geteuid() != 0, "this test needs to be run as root")
-    def test_crash_setuid_drop(self):
+    def test_crash_setuid_drop(self) -> None:
         """Report generation for setuid program which drops root."""
         resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
 
@@ -717,7 +730,7 @@ class T(unittest.TestCase):
         )
 
     @unittest.skipIf(os.geteuid() != 0, "this test needs to be run as root")
-    def test_crash_setuid_unpackaged(self):
+    def test_crash_setuid_unpackaged(self) -> None:
         """Report generation for unpackaged setuid program."""
         # create suid root executable in a path we can modify which apport
         # regards as not packaged
@@ -754,7 +767,7 @@ class T(unittest.TestCase):
         self.assertEqual(pr["Signal"], "11")
         self.assertEqual(pr["ExecutablePath"], self.TEST_EXECUTABLE)
 
-    def test_core_dump_packaged_sigquit_via_socket(self):
+    def test_core_dump_packaged_sigquit_via_socket(self) -> None:
         """Executable create core files via socket, no report for SIGQUIT."""
         resource.setrlimit(resource.RLIMIT_CORE, (-1, -1))
         self.do_crash(
@@ -940,7 +953,7 @@ class T(unittest.TestCase):
             search_map_mock.assert_called()
 
         # call apport like systemd does via socket activation
-        def child_setup():
+        def child_setup() -> None:
             os.environ["LISTEN_FDNAMES"] = "connection"
             os.environ["LISTEN_FDS"] = "1"
             os.environ["LISTEN_PID"] = str(os.getpid())
@@ -981,9 +994,7 @@ class T(unittest.TestCase):
         )
         self.assertNotEqual(gdb.stdout.strip(), "")
 
-    def _check_report(
-        self, expect_report: bool = True, expected_owner: int | None = None
-    ) -> None:
+    def _check_report(self, expect_report=True, expected_owner=None):
         if not expect_report:
             self.assertEqual(apport.fileutils.get_all_reports(), [])
             return
@@ -1002,7 +1013,12 @@ class T(unittest.TestCase):
             st.st_uid, expected_owner, f"{self.test_report} has correct owner"
         )
 
-    def create_test_process(self, command=None, uid=None, args=None):
+    def create_test_process(
+        self,
+        command: str | None = None,
+        uid: int | None = None,
+        args: list[str] | None = None,
+    ) -> subprocess.Popen:
         """Spawn test executable.
 
         Wait until it is fully running, and return its process.
@@ -1033,9 +1049,33 @@ class T(unittest.TestCase):
             else:
                 break
 
-        time.sleep(0.3)  # needs some more setup time
+        # sleep command needs extra time to get into "sleeping" state
+        if command == self.TEST_EXECUTABLE:
+            wait_for_sleeping_state(process.pid)
+
         return process
 
+    def test_create_test_sleep_process(self) -> None:
+        """Test create_test_process() helper method with sleep process."""
+        proc = self.create_test_process()
+        try:
+            self.assertEqual(psutil.Process(proc.pid).status(), "sleeping")
+        finally:
+            proc.kill()
+            proc.wait()
+
+    @unittest.mock.patch("tests.helper.wait_for_sleeping_state")
+    def test_create_test_non_sleep_process(self, wait_sleep_mock: MagicMock) -> None:
+        """Test create_test_process() helper method with non-sleep process."""
+        with (
+            unittest.mock.patch("os.access"),
+            unittest.mock.patch("subprocess.Popen"),
+            unittest.mock.patch("tests.integration.test_signal_crashes.open"),
+        ):
+            self.create_test_process(command="echo")
+
+        wait_sleep_mock.assert_not_called()
+
     # pylint: disable-next=too-many-arguments
     def do_crash(
         self,
@@ -1044,7 +1084,7 @@ class T(unittest.TestCase):
         command: str | None = None,
         expected_command: str | None = None,
         uid: int | None = None,
-        expect_corefile_owner: str | None = None,
+        expect_corefile_owner: int | None = None,
         args: list[str] | None = None,
         suid_dumpable: int = 1,
         hook_before_apport: Callable | None = None,
@@ -1109,7 +1149,7 @@ class T(unittest.TestCase):
             raise
 
         try:
-            command_process = self.wait_for_gdb_child_process(
+            command_process = self.wait_for_gdb_sleeping_child_process(
                 gdb.pid, expected_command or command
             )
 
@@ -1252,7 +1292,9 @@ class T(unittest.TestCase):
 
     @unittest.mock.patch("os.path.exists")
     @unittest.mock.patch("time.sleep")
-    def test_wait_for_core_file_core_not_created(self, sleep_mock, exists_mock):
+    def test_wait_for_core_file_core_not_created(
+        self, sleep_mock: MagicMock, exists_mock: MagicMock
+    ) -> None:
         """Test wait_for_core_file() helper runs into timeout for core file."""
         exists_mock.return_value = False
         with self.assertRaises(AssertionError):
@@ -1263,7 +1305,9 @@ class T(unittest.TestCase):
     @unittest.mock.patch("os.path.exists")
     @unittest.mock.patch("psutil.Process", spec=psutil.Process)
     @unittest.mock.patch("time.sleep")
-    def test_wait_for_core_file_timeout(self, sleep_mock, process_mock, exists_mock):
+    def test_wait_for_core_file_timeout(
+        self, sleep_mock: MagicMock, process_mock: MagicMock, exists_mock: MagicMock
+    ) -> None:
         """Test wait_for_core_file() helper runs into timeout."""
         popenfile = collections.namedtuple("popenfile", ["path"])
         exists_mock.return_value = True
@@ -1277,7 +1321,9 @@ class T(unittest.TestCase):
     # False positive return statement for unittest.TestCase.fail
     # See https://github.com/pylint-dev/pylint/issues/4167
     # pylint: disable-next=inconsistent-return-statements
-    def wait_for_gdb_child_process(self, gdb_pid: int, command: str) -> psutil.Process:
+    def wait_for_gdb_sleeping_child_process(
+        self, gdb_pid: int, command: str
+    ) -> psutil.Process:
         """Wait until GDB execv()ed the child process."""
         gdb_process = psutil.Process(gdb_pid)
         timeout = 0.0
@@ -1285,7 +1331,7 @@ class T(unittest.TestCase):
             gdb_children = gdb_process.children()
             for process in gdb_children:
                 try:
-                    if process.status() == "tracing-stop":
+                    if process.status() != "sleeping":
                         continue
                     cmdline = process.cmdline()
                 except psutil.NoSuchProcess:  # pragma: no cover
@@ -1302,36 +1348,39 @@ class T(unittest.TestCase):
         )
 
     @unittest.mock.patch("time.sleep")
-    def test_wait_for_gdb_child_process(self, sleep_mock):
-        """Test wait_for_gdb_child_process() helper method."""
+    def test_wait_for_gdb_sleeping_child_process(self, sleep_mock: MagicMock) -> None:
+        """Test wait_for_gdb_sleeping_child_process() helper method."""
         child = MagicMock(spec=psutil.Process)
-        child.status.side_effect = ["tracing-stop", "running", "sleeping"]
-        child.cmdline.side_effect = [
-            ["/bin/sh", "-c", f"exec {self.TEST_EXECUTABLE}"],
-            [self.TEST_EXECUTABLE] + self.TEST_ARGS,
+        child.status.side_effect = [
+            "tracing-stop",  # child not yet started
+            "running",  # shell wrapper running
+            "sleeping",  # child ready
         ]
+        child.cmdline.side_effect = [[self.TEST_EXECUTABLE] + self.TEST_ARGS]
         with unittest.mock.patch("psutil.Process", spec=psutil.Process) as process_mock:
             process_mock.return_value.children.side_effect = [
-                [],
+                [],  # gdb hasn't started the child process yet
                 [child],  # child not started (tracing-stop)
                 [child],  # shell wrapper running
                 [child],  # child ready
             ]
 
-            self.wait_for_gdb_child_process(123456789, self.TEST_EXECUTABLE)
+            self.wait_for_gdb_sleeping_child_process(123456789, self.TEST_EXECUTABLE)
 
         sleep_mock.assert_called_with(0.1)
         self.assertEqual(sleep_mock.call_count, 3)
         self.assertEqual(child.status.call_count, 3)
-        self.assertEqual(child.cmdline.call_count, 2)
+        self.assertEqual(child.cmdline.call_count, 1)
 
     @unittest.mock.patch("psutil.Process", spec=psutil.Process)
     @unittest.mock.patch("time.sleep")
-    def test_wait_for_gdb_child_process_timeout(self, sleep_mock, process_mock):
-        """Test wait_for_gdb_child_process() helper runs into timeout."""
+    def test_wait_for_gdb_sleeping_child_process_timeout(
+        self, sleep_mock: MagicMock, process_mock: MagicMock
+    ) -> None:
+        """Test wait_for_gdb_sleeping_child_process() helper runs into timeout."""
         process_mock.return_value.children.return_value = []
         with unittest.mock.patch.object(self, "fail") as fail_mock:
-            self.wait_for_gdb_child_process(123456789, self.TEST_EXECUTABLE)
+            self.wait_for_gdb_sleeping_child_process(123456789, self.TEST_EXECUTABLE)
         fail_mock.assert_called_once()
         sleep_mock.assert_called_with(0.1)
         self.assertEqual(sleep_mock.call_count, 51)
