@@ -6,7 +6,7 @@ import re
 import subprocess
 import unittest
 import unittest.mock
-from unittest.mock import MagicMock
+from unittest.mock import MagicMock, Mock
 
 import apport.hookutils
 
@@ -86,17 +86,17 @@ class TestHookutils(unittest.TestCase):
         )
 
     @unittest.mock.patch("apport.hookutils.root_command_output")
-    def test_attach_dmesg(self, root_command_output_mock):
+    def test_attach_dmesg(self, root_command_output_mock: MagicMock) -> None:
         """attach_dmesg()"""
         root_command_output_mock.return_value = "[30804.972250] CPU0 is up"
 
-        report = {}
+        report: dict[str, str] = {}
         apport.hookutils.attach_dmesg(report)
         self.assertEqual(report, {"CurrentDmesg": "[30804.972250] CPU0 is up"})
 
         root_command_output_mock.assert_called_once_with(["dmesg"])
 
-    def test_dmesg_overwrite(self):
+    def test_dmesg_overwrite(self) -> None:
         """attach_dmesg() does not overwrite already existing data"""
         report = {"CurrentDmesg": "existingcurrent"}
 
@@ -144,7 +144,7 @@ class TestHookutils(unittest.TestCase):
             ["journalctl", "--priority=warning", "-b", "--lines=1000"],
         )
 
-    def test_path_to_key(self):
+    def test_path_to_key(self) -> None:
         """Transform a file path to a valid report key."""
         self.assertEqual(apport.hookutils.path_to_key("simple.txt"), "simple.txt")
         self.assertEqual(
@@ -157,7 +157,7 @@ class TestHookutils(unittest.TestCase):
 
     @unittest.mock.patch("subprocess.Popen")
     @unittest.mock.patch("os.path.exists", MagicMock(return_value=True))
-    def test_recent_syslog_journald_cmd(self, popen_mock):
+    def test_recent_syslog_journald_cmd(self, popen_mock: MagicMock) -> None:
         class _SkipPopen(Exception):
             pass
 
@@ -186,3 +186,42 @@ class TestHookutils(unittest.TestCase):
             apport.hookutils.attach_upstart_logs({}, "apport")
         with self.assertWarns(PendingDeprecationWarning):
             apport.hookutils.attach_upstart_overrides({}, "nonexisting")
+
+    def test_recent_syslog_race_condition(self) -> None:
+        """Test recent_syslog reads stdout buffer after process completion.
+
+        LP: #2073935
+        """
+        with unittest.mock.patch("apport.hookutils.subprocess.Popen") as popen_mock:
+            process = unittest.mock.Mock()
+            popen_mock.return_value.__enter__.return_value = process
+            process.returncode = 0
+
+            process.poll = Mock(return_value=0)
+            process.stdout = MagicMock()
+            process.stdout.__iter__.side_effect = [iter([b"content"])]
+
+            match_content = apport.hookutils.recent_syslog(
+                re.compile("."), path="/nonexisting"
+            )
+            self.assertEqual(match_content, "content")
+
+    def test_recent_syslog_long_process(self) -> None:
+        """Test recent_syslog retrieves entire stdout."""
+        with unittest.mock.patch("apport.hookutils.subprocess.Popen") as popen_mock:
+            process = unittest.mock.Mock()
+            popen_mock.return_value.__enter__.return_value = process
+            process.returncode = 0
+
+            process.poll = Mock(side_effect=[None, 0])
+            process.stdout = MagicMock()
+            process.stdout.__iter__.side_effect = [
+                iter([b"test\n"]),
+                iter([b"content\n"]),
+            ]
+
+            match_content = apport.hookutils.recent_syslog(
+                re.compile("."), path="/nonexisting"
+            )
+
+            self.assertEqual(match_content, "test\ncontent\n")
